@@ -141,32 +141,25 @@ about_verb_cb (BonoboUIComponent *uic,
 	};
 	const char *translator_credits = _("translator_credits");
 	
-	if (quick_lounge->about_dialog != NULL) {
-		gtk_window_present (GTK_WINDOW (quick_lounge->about_dialog));
-                return;
-	}
-	
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "quick-lounge-applet.png", TRUE, NULL);
-        pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-        g_free(file);
+	if (file != NULL) {
+		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+		g_free(file);
+	}
 
-	quick_lounge->about_dialog = gnome_about_new (_("Launchers List"), 
-						      VERSION,
-						      "Copyright \xc2\xa9 2002-2004 Free Software Foundation, Inc.",
-						      _("Organize your favorite applications on the Panel"),
-						      authors,
-						      documenters,
-						      strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-						      pixbuf);
+	gtk_show_about_dialog (NULL,
+			       "name", _("Launchers List"),
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 2002-2004 Free Software Foundation, Inc.",
+			       "comments", _("Organize your favorite applications on the Panel"),
+			       "authors", authors,
+			       "documenters", documenters,
+			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			       "logo", pixbuf,
+			       NULL);
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (quick_lounge->about_dialog), GNOME_ICONDIR "quick-lounge-applet.png");
-
-	g_signal_connect (G_OBJECT (quick_lounge->about_dialog), 
-			  "destroy",
-			  G_CALLBACK (gtk_widget_destroyed), 
-			  &quick_lounge->about_dialog);
-
-	gtk_widget_show_all (quick_lounge->about_dialog);
+	if (pixbuf)
+		g_object_unref (pixbuf);
 }
 
 
@@ -224,8 +217,6 @@ applet_destroy (GtkWidget    *applet,
 {
 	/* free memory */
 
-	if (quick_lounge->about_dialog != NULL)
-                gtk_widget_destroy (quick_lounge->about_dialog);
 	if (quick_lounge->prop_dialog != NULL)
                 gtk_widget_destroy (quick_lounge->prop_dialog);
 
@@ -283,7 +274,7 @@ applet_change_background (PanelApplet               *applet,
 	gtk_widget_set_style (GTK_WIDGET (applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-	g_object_unref (rc_style);
+	gtk_rc_style_unref (rc_style);	
 	
 	switch (type) {
 	case PANEL_COLOR_BACKGROUND:
@@ -298,6 +289,7 @@ applet_change_background (PanelApplet               *applet,
 			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
 		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
 		gtk_widget_set_style (GTK_WIDGET (applet), style);
+		g_object_unref (style);
 		break;
 		
 	case PANEL_NO_BACKGROUND:
@@ -675,7 +667,26 @@ new_launcher_dialog_response_cb (GtkWidget *dialog,
 	pos = GPOINTER_TO_INT (ppos);
 
 	if (response == GTK_RESPONSE_HELP) {
-		/* FIXME */
+		GError *error = NULL;
+
+		gnome_help_display_desktop_on_screen (NULL,
+						      "user-guide",
+						      "user-guide.xml",
+						      "gospanel-52",
+						      gtk_window_get_screen (GTK_WINDOW (dialog)),
+						      &error);
+
+		if (error) {
+			GtkWidget *message_dialog;
+			message_dialog = gtk_message_dialog_new (NULL, 0,
+								 GTK_MESSAGE_ERROR,
+								 GTK_BUTTONS_OK,
+								 _("There was an error displaying help: %s"),
+								 error->message);
+			g_error_free (error);
+			gtk_dialog_run (GTK_DIALOG (message_dialog));
+			gtk_widget_destroy (message_dialog);
+		}
 		
 	} else if (response == GTK_RESPONSE_OK) { 
 		GnomeDesktopItem *ditem;
@@ -852,19 +863,9 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	/**/
 
-	item = gtk_image_menu_item_new_with_mnemonic (_("Add _New Launcher"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_widget_show_all (item);
-
-	g_signal_connect_swapped (G_OBJECT (item), 
-				  "activate",
-				  G_CALLBACK (add_launcher_cb), 
-				  button);
-
-	/**/
-
 	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Existing Launcher"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
 	gtk_widget_show_all (item);
 
 	g_signal_connect_swapped (G_OBJECT (item), 
@@ -876,6 +877,7 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Space"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
 	gtk_widget_show_all (item);
 
 	g_signal_connect_swapped (G_OBJECT (item), 
@@ -885,6 +887,18 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	/**/
 
+	item = gtk_image_menu_item_new_with_mnemonic (_("Add _New Launcher"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU));
+	gtk_widget_show_all (item);
+
+	g_signal_connect_swapped (G_OBJECT (item), 
+				  "activate",
+				  G_CALLBACK (add_launcher_cb), 
+				  button);
+
+	/**/
+
 	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 	gtk_widget_show_all (item);
